const path = require('path')
const Webpack = require('webpack')
const ExtractTextPlugin = require('extract-text-webpack-plugin')
const DashboardPlugin = require('webpack-dashboard/plugin')
const configurationInfo = require('./readConfigure.js')
const generatePages = configurationInfo.generatePages
const webpackBaseConfig = {
  entry: configurationInfo.packEntryFiles,
  output: {
    filename: '[name].[chunkhash].js',
    path: path.resolve(__dirname, '../dist'),
    publicPath: 'http://localhost:8080/assets/'
  },
  resolve: {
    alias: {
      Fed: path.resolve(__dirname, '../fed'),
      Components: path.resolve(__dirname, '../fed/components')
    },
    extensions: ['.ts', 'tsx', '.js', '.json']
  },
  module: {
    rules: [
      {
        test: /\.jsx$/,
        exclude: [path.resolve(__dirname, '../node_modules')],
        use: ['babel-loader']
      },
      {
        test: /\.less$/,
        use: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: ['css-loader', 'less-loader']
        })
      },
      {
        test: /\.tsx?$/,
        exclude: /node_modules/,
        use: [
          {
            loader: 'babel-loader',
            options: {
              babelrc: true,
              plugins: ['react-hot-loader/babel']
            }
          },
          'ts-loader'
        ]
      },
      {
        enforce: 'pre',
        test: /\.js$/,
        loader: 'source-map-loader'
      }
    ]
  },
  optimization: {
    splitChunks: {
      chunks: 'all',
      cacheGroups: {
        vendors: {
          name: 'vendors',
          minChunks: 2
        }
      }
    },
    runtimeChunk: {
      name: 'manifest'
    }
  },
  plugins: [
    new Webpack.NamedChunksPlugin(),
    new ExtractTextPlugin({
      filename: '[name].[contenthash].css',
      allChunks: true
    }),
    new DashboardPlugin()
  ].concat(generatePages(configurationInfo.packEntryFiles, {
    template: path.resolve(__dirname, '../fed/template.ejs'),
    preStyles: configurationInfo.templateFiles.preStyles,
    preScripts: configurationInfo.templateFiles.preScripts,
    bodyScripts: configurationInfo.templateFiles.bodyScripts
  }))
}

module.exports = webpackBaseConfig
